pandas.Series
=============

.. currentmodule:: pandas

.. autoclass:: Series

   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      Series.abs
      Series.add
      Series.add_prefix
      Series.add_suffix
      Series.align
      Series.all
      Series.any
      Series.append
      Series.apply
      Series.argmax
      Series.argmin
      Series.argsort
      Series.as_blocks
      Series.as_matrix
      Series.asfreq
      Series.asof
      Series.astype
      Series.at_time
      Series.autocorr
      Series.between
      Series.between_time
      Series.bfill
      Series.bool
      Series.clip
      Series.clip_lower
      Series.clip_upper
      Series.combine
      Series.combine_first
      Series.compound
      Series.consolidate
      Series.convert_objects
      Series.copy
      Series.corr
      Series.count
      Series.cov
      Series.cummax
      Series.cummin
      Series.cumprod
      Series.cumsum
      Series.describe
      Series.diff
      Series.div
      Series.divide
      Series.dot
      Series.drop
      Series.drop_duplicates
      Series.dropna
      Series.duplicated
      Series.eq
      Series.ffill
      Series.fillna
      Series.filter
      Series.first
      Series.first_valid_index
      Series.floordiv
      Series.from_array
      Series.from_csv
      Series.ge
      Series.get
      Series.get_dtype_counts
      Series.get_ftype_counts
      Series.get_value
      Series.get_values
      Series.groupby
      Series.gt
      Series.head
      Series.hist
      Series.idxmax
      Series.idxmin
      Series.iget
      Series.iget_value
      Series.interpolate
      Series.irow
      Series.isin
      Series.isnull
      Series.item
      Series.iteritems
      Series.iterkv
      Series.keys
      Series.kurt
      Series.kurtosis
      Series.last
      Series.last_valid_index
      Series.le
      Series.load
      Series.lt
      Series.mad
      Series.map
      Series.mask
      Series.max
      Series.mean
      Series.median
      Series.min
      Series.mod
      Series.mode
      Series.mul
      Series.multiply
      Series.ne
      Series.nonzero
      Series.notnull
      Series.nunique
      Series.order
      Series.pct_change
      Series.plot
      Series.pop
      Series.pow
      Series.prod
      Series.product
      Series.ptp
      Series.put
      Series.quantile
      Series.radd
      Series.rank
      Series.ravel
      Series.rdiv
      Series.reindex
      Series.reindex_axis
      Series.reindex_like
      Series.rename
      Series.rename_axis
      Series.reorder_levels
      Series.repeat
      Series.replace
      Series.resample
      Series.reset_index
      Series.reshape
      Series.rfloordiv
      Series.rmod
      Series.rmul
      Series.round
      Series.rpow
      Series.rsub
      Series.rtruediv
      Series.save
      Series.select
      Series.set_value
      Series.shift
      Series.skew
      Series.sort
      Series.sort_index
      Series.sortlevel
      Series.squeeze
      Series.std
      Series.sub
      Series.subtract
      Series.sum
      Series.swapaxes
      Series.swaplevel
      Series.tail
      Series.take
      Series.to_clipboard
      Series.to_csv
      Series.to_dense
      Series.to_dict
      Series.to_frame
      Series.to_hdf
      Series.to_json
      Series.to_msgpack
      Series.to_period
      Series.to_pickle
      Series.to_sparse
      Series.to_string
      Series.to_timestamp
      Series.tolist
      Series.transpose
      Series.truediv
      Series.truncate
      Series.tshift
      Series.tz_convert
      Series.tz_localize
      Series.unique
      Series.unstack
      Series.update
      Series.valid
      Series.value_counts
      Series.var
      Series.view
      Series.where
      Series.xs




   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      Series.T
      Series.at
      Series.axes
      Series.base
      Series.blocks
      Series.data
      Series.dtype
      Series.dtypes
      Series.empty
      Series.flags
      Series.ftype
      Series.ftypes
      Series.iat
      Series.iloc
      Series.imag
      Series.is_copy
      Series.is_time_series
      Series.ix
      Series.loc
      Series.ndim
      Series.real
      Series.shape
      Series.size
      Series.strides
      Series.values
      Series.weekday


